@@ -2,7 +2,7 @@ hmLoadTopic({
 hmKeywords:"Hex Compare,Hex Compare session settings",
 hmTitle:"Hex Compare Settings",
 hmDescription:"Pick Session > Session Settings to open the Session Settings dialog.",
-hmPrevLink:"sessiontablesheets.html",
+hmPrevLink:"sessiontablerows.html",
 hmNextLink:"sessionhexspecs.html",
 hmParentLink:"session_settings.html",
 hmBreadCrumbs:"<a href=\"settings_reference.html\">Settings Reference<\/a> &gt; <a href=\"session_settings.html\">Session Settings<\/a>",
