@@ -1,82 +1,82 @@
-pageinfo = [[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
+pageinfo = [[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
 	[1715027042,0,0,0,null],
 	[1398282942,0,0,0,null],
 	[1715027042,0,0,0,null],
@@ -92,141 +92,141 @@ pageinfo = [[1744326470,0,0,0,null],
 	[1398282942,0,0,0,null],
 	[1398282942,0,0,0,null],
 	[1716915102,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null],
-	[1744326470,0,0,0,null]];
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null],
+	[1753292994,0,0,0,null]];
 pagedata = [ ["./3-way_merge_concepts.html","3-way Merge Concepts","A merge session helps you combine separate sets of changes into a new version of the data, accommodating both sets of changes.","./images/zoomimage.jpg"],
 ["./archive_files.html","Archive Files","Archives are files that contain other files, such as .zip.  Beyond Compare displays them as folders, with a zipper icon, but by default treat...","./images/zoomimage.jpg"],
 ["./bcclipmain.html","Clipboard Compare Overview","Clipboard Compare runs in the background, keeping track of every time the Windows clipboard is updated with text.  It appears in the Windows ...","./images/zoomimage.jpg"],
@@ -277,7 +277,7 @@ pagedata = [ ["./3-way_merge_concepts.html","3-way Merge Concepts","A merge sess
 ["./dlgsnapshot.html","Saving Snapshots","To save a snapshot Pick Tools &#62; Save Snapshot . Enter the path of the folder tree to be saved.  If you are currently in a folder view, you...","./images/zoomimage.jpg"],
 ["./dlgsourcecontrolmanager.html","Source Control Integration","Pick Tools &#62; Source Control Integration to associate folders with your SCC-compatible source control application so that Beyond Compare can off...","./images/zoomimage.jpg"],
 ["./dlgsupport.html","Reporting Problems","If you have found a problem with Beyond Compare, we would like to hear from you!","./images/zoomimage.jpg"],
-["./dlgtablecolhandling.html","Editing a Column Definition","The column Handling dialog allows you to set options for each comparison column.  A subset of this dialog is used to set default handling for...","./images/zoomimage.jpg"],
+["./dlgtablecolhandling.html","Editing Column Handling","The Column Handling dialog allows you to set options for each comparison column.  A subset of this dialog is used to set default handling for...","./images/zoomimage.jpg"],
 ["./dlgtextfindinfiles.html","Finding Text in Files","To locate specific text in multiple files, pick Search &#62; Find in Files .","./images/zoomimage.jpg"],
 ["./dlgtextgrammaritem.html","Editing a Grammar Item","Pick an existing Element name from the dropdown list or enter your own new name.","./images/zoomimage.jpg"],
 ["./dlgtextreplacementitem.html","Editing a Text Replacement Item","Specify the Text to find and the Replace with text.","./images/zoomimage.jpg"],
@@ -295,8 +295,8 @@ pagedata = [ ["./3-way_merge_concepts.html","3-way Merge Concepts","A merge sess
 ["./formattable.html","Table Format Settings","Table formats are file formats used by the Table Compare session type.","./images/zoomimage.jpg"],
 ["./formattableconversion.html","Table Format Conversion Settings","The Conversion tab defines how files should be loaded and saved.","./images/zoomimage.jpg"],
 ["./formattablegeneral.html","Table Format General Settings","The Mask is a set of file types to be associated with this file format.","./images/zoomimage.jpg"],
-["./formattableregional.html","Table Format Regional Settings","Mark the Use system checkbox to use your system&#39;s Regional Settings.  Otherwise, pick the Decimal separator and Thousands separator to be use...","./images/zoomimage.jpg"],
-["./formattabletype.html","Table Format Type Settings","The Type tab defines the syntax of the data file. Delimited text files Pick Delimited if the fields are separated by a delimiter character such as...","./images/zoomimage.jpg"],
+["./formattableregional.html","Table Format Regional Settings","Mark the Use system checkbox to use your system&#39;s Regional Settings.","./images/zoomimage.jpg"],
+["./formattabletype.html","Table Format Type Settings","The Type tab defines the syntax of the data file. Mark the Detect checkbox to have the program automatically determine whether fields are separate...","./images/zoomimage.jpg"],
 ["./formattext.html","Text Format Settings","Text formats are file formats used by the Text Compare and Text Merge session types.","./images/zoomimage.jpg"],
 ["./formattextconversion.html","Text Format Conversion Settings","The Conversion tab defines how files should be loaded and saved.","./images/zoomimage.jpg"],
 ["./formattextgeneral.html","Text Format General Settings","The Mask is a set of file types to be associated with this file format.","./images/zoomimage.jpg"],
@@ -411,17 +411,17 @@ pagedata = [ ["./3-way_merge_concepts.html","3-way Merge Concepts","A merge sess
 ["./sessionreg.html","Registry Compare Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
 ["./sessionregspecs.html","Registry Compare Spec Settings","Specify the files to be compared. The Description can include any text you want.","./images/zoomimage.jpg"],
 ["./sessiontable.html","Table Compare Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
-["./sessiontablealignment.html","Table Compare Alignment Settings","The Alignment tab settings control the algorithm for aligning rows in the comparison.","./images/zoomimage.jpg"],
 ["./sessiontablecolumns.html","Table Compare Column Settings","Each line in the display represents a comparison column, and shows:","./images/zoomimage.jpg"],
 ["./sessiontableformats.html","Table Compare File Format Settings","Specify the file format to be used when reading the left and/or right files.  The default selection is Detected, which means the file format ...","./images/zoomimage.jpg"],
-["./sessiontablesheets.html","Table Compare Sheet Settings","Each line in the display represents a sheet in the table.","./images/zoomimage.jpg"],
+["./sessiontablerows.html","Table Compare Row Settings","These settings control the algorithm for aligning rows in the comparison when no keys are defined.","./images/zoomimage.jpg"],
+["./sessiontablesheets.html","Table Compare Sheet Settings","Each line in the display represents a comparison sheet, and shows:","./images/zoomimage.jpg"],
 ["./sessiontablespecs.html","Table Compare Spec Settings","Specify the files to be compared. Mark Disable editing to protect content from being changed on disk. The Description can include any text you want.","./images/zoomimage.jpg"],
 ["./sessiontext.html","Text Compare Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
-["./sessiontextalignment.html","Text Compare Alignment Settings","The Alignment tab settings control the algorithm for aligning lines in the comparison.","./images/zoomimage.jpg"],
+["./sessiontextalignment.html","Text Compare Alignment Settings","These settings control the algorithm for aligning lines in the comparison.","./images/zoomimage.jpg"],
 ["./sessiontextformats.html","Text Compare File Format Settings","Specify the file format to be used when reading the left and/or right files.  The default selection is Detected, which means the file format ...","./images/zoomimage.jpg"],
 ["./sessiontextimportance.html","Text Compare Importance Settings","These settings control which differences you consider important in the current session.  Important differences will be colored red in the com...","./images/zoomimage.jpg"],
 ["./sessiontextmerge.html","Text Merge Settings","Pick Session &#62; Session Settings to open the Session Settings dialog.","./images/zoomimage.jpg"],
-["./sessiontextmergealignment.html","Text Merge Alignment Settings","The Alignment tab settings control the algorithm for aligning lines in the comparison.","./images/zoomimage.jpg"],
+["./sessiontextmergealignment.html","Text Merge Alignment Settings","These settings control the algorithm for aligning lines in the comparison.","./images/zoomimage.jpg"],
 ["./sessiontextmergeformats.html","Text Merge File Format Settings","Specify the file format to be used when reading the input files.  The default selection is Detected, which means the file format will be sele...","./images/zoomimage.jpg"],
 ["./sessiontextmergeimportance.html","Text Merge Importance Settings","These settings control which differences you consider important in the current session.  Important differences will be colored red in the com...","./images/zoomimage.jpg"],
 ["./sessiontextmergespecs.html","Text Merge Spec Settings","Specify the files to be merged. Merge to defines the destination file of the merge results. The Description can include any text you want.","./images/zoomimage.jpg"],
